ComponentExtern

Struct ComponentExtern 

pub struct ComponentExtern<'a> {
    pub ty: ComponentItem,
    pub implements: Option<&'a str>,
}
An import or an export from either Component or ComponentInstance.

This records the type of the item that is being imported or exported along with any other metadata associated.

Fields

ty: ComponentItem

The type of this item.

implements: Option<&'a str>

The (implements "...") annotation, if present.