WasmSignature

Struct WasmSignature 

pub struct WasmSignature {
    pub params: Vec<WasmType>,
    pub results: Vec<WasmType>,
    pub indirect_params: bool,
    pub retptr: bool,
}
A core WebAssembly signature with params and results.

Fields

params: Vec<WasmType>

The WebAssembly parameters of this function.

results: Vec<WasmType>

The WebAssembly results of this function.

indirect_params: bool

Whether or not this signature is passing all of its parameters indirectly through a pointer within params.

Note that params still reflects the true wasm parameters of this function, this is auxiliary information for code generators if necessary.

retptr: bool

Whether or not this signature is using a return pointer to store the result of the function, which is reflected either in params or results depending on the context this function is used (e.g. an import or an export).