DecodedWasm

Enum DecodedWasm 

pub enum DecodedWasm {
    WitPackage(Resolve, Id<Package>),
    Component(Resolve, Id<World>),
}
Result of the decode function.

Variants



WitPackage(Resolve, Id<Package>)

The input to decode was one or more binary-encoded WIT package(s).

The full resolve graph is here plus the identifier of the packages that were encoded. Note that other packages may be within the resolve if any of the main packages refer to other, foreign packages.



Component(Resolve, Id<World>)

The input to decode was a component and its interface is specified by the world here.

Implementations



impl DecodedWasm

pub fn resolve(&self) -> &Resolve

Returns the Resolve for WIT types contained.

pub fn package(&self) -> Id<Package>

Returns the main packages of what was decoded.