Enum FunctionKind
pub enum FunctionKind {
Freestanding,
AsyncFreestanding,
Method(Id<TypeDef>),
AsyncMethod(Id<TypeDef>),
Static(Id<TypeDef>),
AsyncStatic(Id<TypeDef>),
Constructor(Id<TypeDef>),
}Variants
Freestanding
A freestanding function.
interface foo {
the-func: func();
}AsyncFreestanding
An async freestanding function.
interface foo {
the-func: async func();
}Method(Id<TypeDef>)
A resource method where the first parameter is implicitly
borrow<T>.
interface foo {
resource r {
the-func: func();
}
}AsyncMethod(Id<TypeDef>)
An async resource method where the first parameter is implicitly
borrow<T>.
interface foo {
resource r {
the-func: async func();
}
}Static(Id<TypeDef>)
A static resource method.
interface foo {
resource r {
the-func: static func();
}
}AsyncStatic(Id<TypeDef>)
An async static resource method.
interface foo {
resource r {
the-func: static async func();
}
}Constructor(Id<TypeDef>)
A resource constructor where the return value is implicitly own<T>.
interface foo {
resource r {
constructor();
}
}Implementations
impl FunctionKind
impl FunctionKind