Enum LiftLowerAbi
pub enum LiftLowerAbi {
Sync,
AsyncCallback,
AsyncStackful,
}Expand description
Possible lift/lower ABI choices supported when mangling names.
Variants
Sync
Both imports and exports will use the synchronous ABI.
AsyncCallback
Both imports and exports will use the async ABI (with a callback for each export).
AsyncStackful
Both imports and exports will use the async ABI (with no callbacks for exports).
Implementations
impl LiftLowerAbi
impl LiftLowerAbi
pub fn import_variant(self) -> AbiVariant
pub fn import_variant(self) -> AbiVariant
Get the import AbiVariant corresponding to this LiftLowerAbi
pub fn export_variant(self) -> AbiVariant
pub fn export_variant(self) -> AbiVariant
Get the export AbiVariant corresponding to this LiftLowerAbi