Mangling

Enum Mangling 

pub enum Mangling {
    Standard32,
    Legacy,
}
Possible forms of name mangling that are supported by this crate.

Variants



Standard32

The “standard” component model mangling format for 32-bit linear memories. This is specified in WebAssembly/component-model#378



Legacy

The “legacy” name mangling supported in versions 218-and-prior for this crate. This is the original support for how components were created from core wasm modules and this does not correspond to any standard. This is preserved for now while tools transition to the new scheme.