Enum ManglingAndAbi
pub enum ManglingAndAbi {
Standard32,
Legacy(LiftLowerAbi),
}Expand description
Combination of Mangling and LiftLowerAbi.
Variants
Standard32
See Mangling::Standard32.
As of this writing, the standard name mangling only supports the synchronous ABI.
Legacy(LiftLowerAbi)
See Mangling::Legacy and LiftLowerAbi.
Implementations
impl ManglingAndAbi
impl ManglingAndAbi
pub fn import_variant(self) -> AbiVariant
pub fn import_variant(self) -> AbiVariant
Get the import AbiVariant corresponding to this ManglingAndAbi
pub fn export_variant(self) -> AbiVariant
pub fn export_variant(self) -> AbiVariant
Get the export AbiVariant corresponding to this ManglingAndAbi
pub fn sync(self) -> ManglingAndAbi
pub fn sync(self) -> ManglingAndAbi
Switch the ABI to be sync if it’s async.
pub fn mangling(&self) -> Mangling
pub fn for_func(&self, func: &Function) -> ManglingAndAbi
pub fn for_func(&self, func: &Function) -> ManglingAndAbi
Returns a suitable ManglingAndAbi, based on self, to use for
func.
This handles the case where func is a synchronous function which means
that it’s forced to use the sync ABI no matter what.