Enum Stability
pub enum Stability {
Unknown,
Unstable {
feature: String,
deprecated: Option<Version>,
},
Stable {
since: Version,
deprecated: Option<Version>,
},
}Expand description
Representation of the stability attributes associated with a world, interface, function, or type.
This is added for WebAssembly/component-model#332 where @since and @unstable annotations were added to WIT.
The order of the of enum values is significant since it is used with Ord and PartialOrd
Variants
Unknown
This item does not have either @since or @unstable.
Unstable
@unstable(feature = foo)
This item is explicitly tagged @unstable. A feature name is listed and
this item is excluded by default in Resolve unless explicitly enabled.
Stable
@since(version = 1.2.3)
This item is explicitly tagged with @since as stable since the
specified version. This may optionally have a feature listed as well.
Implementations