Enum WasmExport
pub enum WasmExport<'a> {
Func {
interface: Option<&'a WorldKey>,
func: &'a Function,
kind: WasmExportKind,
},
ResourceDtor {
interface: &'a WorldKey,
resource: Id<TypeDef>,
},
Memory,
Initialize,
Realloc,
}Expand description
Different kinds of exports that can be passed to
Resolve::wasm_export_name to export from core wasm modules.
Variants
Func
A WIT function is being exported, optionally from an interface.
Fields

interface: Option<&'a WorldKey>An optional interface which owns func. Use None for top-level
world function.

kind: WasmExportKindKind of function (normal, post-return, or callback) being exported.
ResourceDtor
A destructor for a resource exported from this module.
Fields
Memory
Linear memory, the one that the canonical ABI uses.
Initialize
An initialization function (not the core wasm start).
Realloc
The general-purpose realloc hook.