WasmImport

Enum WasmImport 

pub enum WasmImport<'a> {
    Func {
        interface: Option<&'a WorldKey>,
        func: &'a Function,
    },
    ResourceIntrinsic {
        interface: Option<&'a WorldKey>,
        resource: Id<TypeDef>,
        intrinsic: ResourceIntrinsic,
    },
    FutureIntrinsic {
        interface: Option<&'a WorldKey>,
        func: &'a Function,
        ty: Option<Id<TypeDef>>,
        intrinsic: FutureIntrinsic,
        exported: bool,
        async_: bool,
    },
    StreamIntrinsic {
        interface: Option<&'a WorldKey>,
        func: &'a Function,
        ty: Option<Id<TypeDef>>,
        intrinsic: StreamIntrinsic,
        exported: bool,
        async_: bool,
    },
}
Possible imports that can be passed to Resolve::wasm_import_name.

Variants



Func

A WIT function is being imported. Optionally from an interface.

Fields

interface: Option<&'a WorldKey>

The name of the interface that the function is being imported from.

If the function is imported directly from the world then this is None.

func: &'a Function

The function being imported.



ResourceIntrinsic

A resource-related intrinsic is being imported.

Fields

interface: Option<&'a WorldKey>

The optional interface to import from, same as WasmImport::Func.

resource: Id<TypeDef>

The resource that’s being operated on.

intrinsic: ResourceIntrinsic

The intrinsic that’s being imported.



FutureIntrinsic

A future-related intrinsic is being imported.

Fields

interface: Option<&'a WorldKey>

The optional interface to import from, same as WasmImport::Func.

func: &'a Function

The function whose signature this future type appears in.

ty: Option<Id<TypeDef>>

The future type appearing in func.find_futures_and_streams(resolve).

Use None for the special unit payload case.

intrinsic: FutureIntrinsic

The intrinsic that’s being imported.

exported: bool

Whether this import is for an exported WIT function.

This controls whether the module name is prefixed with [export].

async_: bool

Whether this intrinsic import is async-lowered.

This is only valid for read/write/cancel intrinsics.



StreamIntrinsic

A stream-related intrinsic is being imported.

Fields

interface: Option<&'a WorldKey>

The optional interface to import from, same as WasmImport::Func.

func: &'a Function

The function whose signature this stream type appears in.

ty: Option<Id<TypeDef>>

The stream type appearing in func.find_futures_and_streams(resolve).

Use None for the special unit payload case.

intrinsic: StreamIntrinsic

The intrinsic that’s being imported.

exported: bool

Whether this import is for an exported WIT function.

This controls whether the module name is prefixed with [export].

async_: bool

Whether this intrinsic import is async-lowered.

This is only valid for read/write/cancel intrinsics.