Enum WorldItem
pub enum WorldItem {
Interface {
id: Id<Interface>,
stability: Stability,
span: Span,
},
Function(Function),
Type {
id: Id<TypeDef>,
span: Span,
},
}Variants
Interface
An interface is being imported or exported from a world, indicating that it’s a namespace of functions.
Function(Function)
A function is being directly imported or exported from this world.
Type
A type is being exported from this world.
Note that types are never imported into worlds at this time.
Implementations