Struct CloneMaps
pub struct CloneMaps { /* private fields */ }Expand description
Represents the results of cloning types and/or interfaces as part of a
Resolve::merge_worlds operation.
Implementations
impl CloneMaps
impl CloneMaps
pub fn types(&self) -> &HashMap<Id<TypeDef>, Id<TypeDef>>
pub fn types(&self) -> &HashMap<Id<TypeDef>, Id<TypeDef>>
The types cloned during a Resolve::merge_worlds operation.
The key is the original type, and the value is the clone.
pub fn interfaces(&self) -> &HashMap<Id<Interface>, Id<Interface>>
pub fn interfaces(&self) -> &HashMap<Id<Interface>, Id<Interface>>
The interfaces cloned during a Resolve::merge_worlds operation.
The key is the original interface, and the value is the clone.