Function

Struct Function 

pub struct Function {
    pub name: String,
    pub kind: FunctionKind,
    pub params: Vec<Param>,
    pub result: Option<Type>,
    pub docs: Docs,
    pub stability: Stability,
    pub span: Span,
}

Fields

name: Stringkind: FunctionKindparams: Vec<Param>result: Option<Type>docs: Docsstability: Stability

Stability attribute for this function.

span: Span

Source span for this function.

Implementations



impl Function

pub fn item_name(&self) -> &str

pub fn parameter_and_result_types(&self) -> impl Iterator<Item = Type>

Returns an iterator over the types used in parameters and results.

Note that this iterator is not transitive, it only iterates over the direct references to types that this function has.

pub fn standard32_core_export_name<'a>( &'a self, interface: Option<&str>, ) -> Cow<'a, str>

Gets the core export name for this function.

pub fn legacy_core_export_name<'a>( &'a self, interface: Option<&str>, ) -> Cow<'a, str>

pub fn core_export_name<'a>( &'a self, interface: Option<&str>, mangling: Mangling, ) -> Cow<'a, str>

Gets the core export name for this function.

pub fn find_futures_and_streams(&self, resolve: &Resolve) -> Vec<Id<TypeDef>>

Collect any future and stream types appearing in the signature of this function by doing a depth-first search over the parameter types and then the result types.

For example, given the WIT function foo: func(x: future<future<u32>>, y: u32) -> stream<u8>, we would return [future<u32>, future<future<u32>>, stream<u8>].

This may be used by binding generators to refer to specific future and stream types when importing canonical built-ins such as stream.new, future.read, etc. Using the example above, the import [future-new-0]foo would indicate a call to future.new for the type future<u32>. Likewise, [future-new-1]foo would indicate a call to future.new for future<future<u32>>, and [stream-new-2]foo would indicate a call to stream.new for stream<u8>.

pub fn is_constructor_shorthand(&self, resolve: &Resolve) -> bool

Check if this function is a resource constructor in shorthand form. I.e. without an explicit return type annotation.

pub fn task_return_import( &self, resolve: &Resolve, interface: Option<&WorldKey>, mangling: Mangling, ) -> (String, String, WasmSignature)

Returns the module, name, and signature to use when importing this function’s task.return intrinsic using the mangling specified.