Struct Interface
pub struct Interface {
pub name: Option<String>,
pub types: IndexMap<String, Id<TypeDef>>,
pub functions: IndexMap<String, Function>,
pub docs: Docs,
pub stability: Stability,
pub package: Option<Id<Package>>,
pub span: Span,
pub clone_of: Option<Id<Interface>>,
}Fields
name: Option<String>Optionally listed name of this interface.
This is None for inline interfaces in worlds.
types: IndexMap<String, Id<TypeDef>>Exported types from this interface.
Export names are listed within the types themselves. Note that the
export name here matches the name listed in the TypeDef.
functions: IndexMap<String, Function>Exported functions from this interface.
docs: DocsDocumentation associated with this interface.
stability: StabilityStability attribute for this interface.
package: Option<Id<Package>>The package that owns this interface.
span: SpanSource span for this interface.
clone_of: Option<Id<Interface>>The interface that this one was cloned from, if any.
Applicable for Resolve::generate_nominal_type_ids.