Struct Package
pub struct Package {
pub name: PackageName,
pub docs: Docs,
pub interfaces: IndexMap<String, Id<Interface>>,
pub worlds: IndexMap<String, Id<World>>,
}Expand description
A WIT package within a Resolve.
A package is a collection of interfaces and worlds. Packages additionally have a unique identifier that affects generated components and uniquely identifiers this particular package.
Fields
name: PackageNameA unique name corresponding to this package.
docs: DocsDocumentation associated with this package.
interfaces: IndexMap<String, Id<Interface>>All interfaces contained in this packaged, keyed by the interface’s name.
worlds: IndexMap<String, Id<World>>All worlds contained in this package, keyed by the world’s name.