Struct Span
pub struct Span { /* private fields */ }Expand description
A span, designating a range of bytes where a token is located.
Uses u32::MAX as a sentinel value to represent unknown spans (e.g.,
decoded from binary).
Implementations
impl Span
impl Span
pub fn new(start: u32, end: u32) -> Span
pub fn adjust(&mut self, offset: u32)
pub fn adjust(&mut self, offset: u32)
Adjusts this span by adding the given byte offset to both start and end.
pub fn set_end(&mut self, new_end: u32)
pub fn set_end(&mut self, new_end: u32)
Sets the end offset. If this is unknown, converts to a zero-width span at that position.