Struct World
pub struct World {
pub name: String,
pub imports: IndexMap<WorldKey, WorldItem>,
pub exports: IndexMap<WorldKey, WorldItem>,
pub package: Option<Id<Package>>,
pub docs: Docs,
pub stability: Stability,
pub includes: Vec<WorldInclude>,
pub span: Span,
}Fields
name: StringThe WIT identifier name of this world.
imports: IndexMap<WorldKey, WorldItem>All imported items into this interface, both worlds and functions.
exports: IndexMap<WorldKey, WorldItem>All exported items from this interface, both worlds and functions.
package: Option<Id<Package>>The package that owns this world.
docs: DocsDocumentation associated with this world declaration.
stability: StabilityStability annotation for this world itself.
includes: Vec<WorldInclude>All the included worlds from this world. Empty if this is fully resolved.
span: SpanSource span for this world.