Enum CodeHint
pub enum CodeHint {
Module,
Component,
}Expand description
Return value of CodeBuilder::hint
Variants
Module
Hint that the code being compiled is a module.
Component
Hint that the code being compiled is a component.