pub struct GcHeapOutOfMemory<T> { /* private fields */ }Expand description
An error returned when attempting to allocate a GC-managed object, but the GC heap is out of memory.
This error wraps an inner T value – which is the host value, if any, that
was passed to [ExternRef::new][crate::ExternRef::new] – and you can
recover this value via the
into_inner method. This lets you
try to allocate the externref again, after performing a GC to hopefully
free up space in the heap, or otherwise do whatever you want with the inner
value.
For errors that occur when attempting to allocate non-externref objects
when the GC heap is at capacity, the T type parameter is just the unit
type ().
Implementations
Sourceimpl<T> GcHeapOutOfMemory<T>
impl<T> GcHeapOutOfMemory<T>
Sourcepub fn into_inner(self) -> T
pub fn into_inner(self) -> T
Recover this error’s inner host value.
Sourcepub fn take_inner(self) -> (T, GcHeapOutOfMemory<()>)
pub fn take_inner(self) -> (T, GcHeapOutOfMemory<()>)
Take this error’s inner host value, but also retain this
GcHeapOutOfMemory with T replaced with ().
This allows you to both extract the inner T if necessary, and also
pass the GcHeapOutOfMemory error to [Store::gc][crate::Store::gc]
calls.