Struct PoolingAllocatorMetrics
pub struct PoolingAllocatorMetrics { /* private fields */ }Expand description
PoolingAllocatorMetrics provides access to runtime metrics of a pooling
allocator configured with crate::InstanceAllocationStrategy::Pooling.
This is a cheap cloneable handle which can be obtained with
Engine::pooling_allocator_metrics.
Implementations
impl PoolingAllocatorMetrics
impl PoolingAllocatorMetrics
pub fn core_instances(&self) -> u64
pub fn core_instances(&self) -> u64
Returns the number of core (module) instances currently allocated.
pub fn component_instances(&self) -> u64
pub fn component_instances(&self) -> u64
Returns the number of component instances currently allocated.
pub fn unused_warm_memories(&self) -> u32
pub fn unused_warm_memories(&self) -> u32
Returns the number of slots for linear memories in this allocator which are not currently in use but were previously used.
A “warm” slot means that there was a previous instantiation of a memory in that slot. Warm slots are favored in general for allocating new memories over using a slot that has never been used before.
pub fn unused_memory_bytes_resident(&self) -> usize
pub fn unused_memory_bytes_resident(&self) -> usize
Returns the number of bytes in this pooling allocator which are not part
of any in-used linear memory slot but were previously used and are kept
resident via the *_keep_resident configuration options.
pub fn unused_warm_tables(&self) -> u32
pub fn unused_warm_tables(&self) -> u32
Returns the number of slots for tables in this allocator which are not currently in use but were previously used.
A “warm” slot means that there was a previous instantiation of a table in that slot. Warm slots are favored in general for allocating new tables over using a slot that has never been used before.
pub fn unused_table_bytes_resident(&self) -> usize
pub fn unused_table_bytes_resident(&self) -> usize
Returns the number of bytes in this pooling allocator which are not part
of any in-used linear table slot but were previously used and are kept
resident via the *_keep_resident configuration options.
pub fn unused_warm_stacks(&self) -> u32
pub fn unused_warm_stacks(&self) -> u32
Returns the number of slots for stacks in this allocator which are not currently in use but were previously used.
A “warm” slot means that there was a previous use of a stack in that slot. Warm slots are favored in general for allocating new stacks over using a slot that has never been used before.
pub fn unused_stack_bytes_resident(&self) -> Option<usize>
pub fn unused_stack_bytes_resident(&self) -> Option<usize>
Returns the number of bytes in this pooling allocator which are not part
of any in-used linear stack slot but were previously used and are kept
resident via the *_keep_resident configuration options.
This returns None if the async_stack_zeroing option is disabled or
if the platform doesn’t manage stacks (e.g. Windows returns None).