Struct Tag
pub struct Tag { /* private fields */ }Expand description
A WebAssembly tag.
Implementations
impl Tag
impl Tag
pub fn new(store: impl AsContextMut, ty: &TagType) -> Result<Tag, Error>
pub fn new(store: impl AsContextMut, ty: &TagType) -> Result<Tag, Error>
Create a new tag instance from a given TagType.
Errors
This function will return an OutOfMemory error when
memory allocation fails. See the OutOfMemory type’s documentation for
details on Wasmtime’s out-of-memory handling.
pub fn debug_index_in_store(&self) -> u64
pub fn debug_index_in_store(&self) -> u64
Returns a stable identifier for this tag within its store.
This allows distinguishing tags when introspecting them e.g. via debug APIs.