Trait Aliasable
pub trait Aliasable { }Expand description
A type that can be aliased in the component model.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
pub trait Aliasable { }A type that can be aliased in the component model.
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".