InterfaceName

Struct InterfaceName 

pub struct InterfaceName<'a>(/* private fields */);
An interface name, stored as a:b/c@1.2.3

Implementations



impl<'a> InterfaceName<'a>

pub fn as_str(&self) -> &'a str

Returns the entire underlying string.

pub fn namespace(&self) -> KebabStr<'a>

Returns the a:b in a:b:c/d/e

pub fn package(&self) -> KebabStr<'a>

Returns the c in a:b:c/d/e

pub fn interface(&self) -> KebabStr<'a>

Returns the d in a:b:c/d/e.

pub fn projection(&self) -> KebabStr<'a>

Returns the d/e in a:b:c/d/e

pub fn version(&self, suffix: Option<&str>) -> Result<Option<Version>, Error>

Returns the 1.2.3 in a:b:c/d/e@1.2.3

The suffix provided here is the optionally specified versionsuffix field in the binary format. This is appended to the version to form the full version, if specified. If None then the name is required to have a full version as-is.