Struct Error
pub struct Error { /* private fields */ }Expand description
A binary reader for WebAssembly modules.
Implementations
impl Error
impl Error
pub fn missing_wasm_feature(&self) -> Option<WasmFeatures>
pub fn missing_wasm_feature(&self) -> Option<WasmFeatures>
Returns Some if this error is due to a disabled Wasm feature.
If the features crate feature is enabled, a returned WasmFeatures
will contain a feature that could be enabled to prevent this error.
Note: This is not comprehensive; None may be returned in some
cases where enabling a feature could avoid the error.