Enum AbiVariant
pub enum AbiVariant {
GuestImport,
GuestExport,
GuestImportAsync,
GuestExportAsync,
GuestExportAsyncStackful,
}Expand description
We use a different ABI for wasm importing functions exported by the host than for wasm exporting functions imported by the host.
Note that this reflects the flavor of ABI we generate, and not necessarily
the way the resulting bindings will be used by end users. See the comments
on the Direction enum in gen-core for details.
The bindings ABI has a concept of a “guest” and a “host”. There are two variants of the ABI, one specialized for the “guest” importing and calling a function defined and exported in the “host”, and the other specialized for the “host” importing and calling a function defined and exported in the “guest”.
Variants
GuestImport
The guest is importing and calling the function.
GuestExport
The guest is defining and exporting the function.
GuestImportAsync
GuestExportAsync
GuestExportAsyncStackful
Implementations
impl AbiVariant
impl AbiVariant