BreakpointEdit

Struct BreakpointEdit 

pub struct BreakpointEdit<'a> { /* private fields */ }
A breakpoint-editing session.

This enables updating breakpoint state (setting or unsetting individual breakpoints or the store-global single-step flag) in a batch. It is more efficient to batch these updates because “re-publishing” the newly patched code, with update breakpoint settings, typically requires a syscall to re-enable execute permissions.

Implementations

Source

impl<'a> BreakpointEdit<'a>

pub fn add_breakpoint(&mut self, module: &Module, pc: u32) -> Result<(), Error>

Add a breakpoint in the given module at the given PC in that module.

If the requested PC does not fall exactly on an opcode boundary, the breakpoint is “slipped” forward to the next available opcode PC.

No effect if the breakpoint is already set.

pub fn remove_breakpoint( &mut self, module: &Module, pc: u32, ) -> Result<(), Error>

Remove a breakpoint in the given module at the given PC in that module.

No effect if the breakpoint was not set.

pub fn single_step(&mut self, enabled: bool) -> Result<(), Error>

Turn on or off single-step mode.

In single-step mode, a breakpoint event is emitted at every Wasm PC.