Struct InterfaceName
pub struct InterfaceName<'a>(/* private fields */);Expand description
An interface name, stored as a:b/c@1.2.3
Implementations
impl<'a> InterfaceName<'a>
impl<'a> InterfaceName<'a>
pub fn projection(&self) -> KebabStr<'a>
pub fn projection(&self) -> KebabStr<'a>
Returns the d/e in a:b:c/d/e
pub fn version(&self, suffix: Option<&str>) -> Result<Option<Version>, Error>
pub fn version(&self, suffix: Option<&str>) -> Result<Option<Version>, Error>
Returns the 1.2.3 in a:b:c/d/e@1.2.3
The suffix provided here is the optionally specified versionsuffix
field in the binary format. This is appended to the version to form the
full version, if specified. If None then the name is required to have
a full version as-is.